---
title: <span class="badge object-type-scalar"></span> MetersSecSquared
---
# <span class="badge object-type-scalar"></span> MetersSecSquared

Acceleration: Meters/sec² (m/sec²)

## Definition

```python
# Acceleration: Meters/sec² (m/sec²)
MetersSecSquared: typing.Literal["accMS2"] = "accMS2"
```
